@@ -70,6 +70,8 @@ class DBConnectionWrapper(Wrapper):
     wraps a database connection and extends the functionality
     to do tasks like put queries into dataframes
     """
+    CURSOR_WRAPPER = DBCursorWrapper
+
     def __init__(self, wrap_name = None, chunked=False, **kwargs):
         
         if kwargs:
@@ -99,7 +101,7 @@ class DBConnectionWrapper(Wrapper):
         Creates a cursor and executes the query for you
         """
         cursor = self._wrapped.cursor()
-        return DBCursorWrapper(cursor, query, args=args)()
+        return self.CURSOR_WRAPPER(cursor, query, args=args)()
 
     #TODO: Add in the ability to pass in params and also index 
     def select_dataframe(self, query, args=()):
@@ -114,14 +116,7 @@ class DBConnectionWrapper(Wrapper):
                             "sudo easy_install pandas")
 
         cursor = self.execute(query, args = args)
-        data = cursor.fetchall()
-        columns = [x[0].lower() for x in cursor.description]
-        
-        #check to see if they have duplicate column names
-        if len(columns)>len(set(columns)):
-            raise Exception("Cannot have duplicate column names " +
-                            "in your query %s, please rename" % columns)
-        return list_to_dataframe(data, columns) 
+        return cursor.as_dataframe()
     
     def select(self, query=None, chunk_name = None, args=()):
         """
@@ -139,7 +134,7 @@ class DBConnectionWrapper(Wrapper):
         if not cursor:
             raise Exception("no cursor found")
 
-        return DBCursorWrapper(cursor, query, args=args)()
+        return self.CURSOR_WRAPPER(cursor, query, args=args)()
  
     def create_connection(self):
         """
